@@ -6,7 +6,10 @@ import (
 	"time"
 
 	"github.com/armosec/kubescape/cautils"
+	"github.com/armosec/opa-utils/objectsenvelopes"
 	"github.com/armosec/opa-utils/reporthandling"
+	"github.com/armosec/opa-utils/score"
+
 	"github.com/golang/glog"
 
 	"github.com/armosec/k8s-interface/k8sinterface"
@@ -64,7 +67,8 @@ func (opaHandler *OPAProcessorHandler) ProcessRulesListenner() {
 		opap.updateResults()
 
 		// update score
-		// opap.updateScore()
+		scoreutil := score.NewScore(opaSessionObj.AllResources)
+		scoreutil.Calculate(opaSessionObj.PostureReport.FrameworkReports)
 
 		// report
 		*opaHandler.reportResults <- opaSessionObj
@@ -161,7 +165,7 @@ func (opap *OPAProcessor) processRule(rule *reporthandling.PolicyRule) (*reporth
 		return nil, nil
 	}
 
-	inputResources, err := reporthandling.RegoResourcesAggregator(rule, getKubernetesObjects(opap.K8SResources, opap.AllResources, rule.Match))
+	inputResources, err := reporthandling.RegoResourcesAggregator(rule, getAllSupportedObjects(opap.K8SResources, opap.AllResources, rule))
 	if err != nil {
 		return nil, fmt.Errorf("error getting aggregated k8sObjects: %s", err.Error())
 	}
@@ -183,20 +187,20 @@ func (opap *OPAProcessor) processRule(rule *reporthandling.PolicyRule) (*reporth
 	if err != nil {
 		return nil, err
 	}
-	inputResources = workloadinterface.ListMapToMeta(enumeratedData)
+	inputResources = objectsenvelopes.ListMapToMeta(enumeratedData)
 	ruleReport.ListInputKinds = workloadinterface.ListMetaIDs(inputResources)
 
 	for i := range inputResources {
 		opap.AllResources[inputResources[i].GetID()] = inputResources[i]
 	}
 
-	failedResources := workloadinterface.ListMapToMeta(ruleReport.GetFailedResources())
+	failedResources := objectsenvelopes.ListMapToMeta(ruleReport.GetFailedResources())
 	for i := range failedResources {
 		if r, ok := opap.AllResources[failedResources[i].GetID()]; !ok {
 			opap.AllResources[failedResources[i].GetID()] = r
 		}
 	}
-	warningResources := workloadinterface.ListMapToMeta(ruleReport.GetWarnignResources())
+	warningResources := objectsenvelopes.ListMapToMeta(ruleReport.GetWarnignResources())
 	for i := range warningResources {
 		if r, ok := opap.AllResources[warningResources[i].GetID()]; !ok {
 			opap.AllResources[warningResources[i].GetID()] = r
