@@ -4,6 +4,7 @@ import (
 	"testing"
 
 	"github.com/armosec/kubescape/cautils"
+	"github.com/armosec/opa-utils/objectsenvelopes"
 	"github.com/armosec/opa-utils/reporthandling"
 	"github.com/armosec/opa-utils/resources"
 
@@ -20,7 +21,7 @@ func TestProcess(t *testing.T) {
 	// set k8s
 	k8sResources := make(cautils.K8SResources)
 	allResources := make(map[string]workloadinterface.IMetadata)
-	imetaObj := workloadinterface.ListMapToMeta(k8sinterface.ConvertUnstructuredSliceToMap(k8sinterface.V1KubeSystemNamespaceMock().Items))
+	imetaObj := objectsenvelopes.ListMapToMeta(k8sinterface.ConvertUnstructuredSliceToMap(k8sinterface.V1KubeSystemNamespaceMock().Items))
 	for i := range imetaObj {
 		allResources[imetaObj[i].GetID()] = imetaObj[i]
 	}
